require 'rails_helper'

RSpec.describe Hermes::ReservationHolder, type: :model do
  it 'has a valid factory' do
    expect(FactoryBot.build(:reservation_holder)).to be_valid
  end

  describe 'update_readers' do
    let(:l1) { create(:lessor)}
    let(:l2) { create(:lessor)}
    let(:l3) { create(:lessor)}
    let(:user1) { create(:user, group_ids: [l1.manager_group_id])}
    let(:user2) { create(:user, group_ids: [l2.manager_group_id])}
    let(:user3) { create(:user, group_ids: [l3.manager_group_id])}
    let!(:rh_public) { create(:reservation_holder, name: 'public', public_read: true)}
    let!(:rh_lessors) { create(:reservation_holder, name: 'lessors', lessors: [l1, l2])}

    it 'public reservation holder works' do
      expect(rh_public.reload.readers.include?(l1.id)).to eq false
      expect(rh_public.reload.readable_by?(user1)).to eq true
      expect(rh_public.reload.readable_by?(user2)).to eq true
      expect(rh_public.reload.readable_by?(user3)).to eq true
    end

    it 'private reservation holder works' do
      expect(rh_lessors.reload.readers.include?("g_#{l1.manager_group_id}")).to eq true
      expect(rh_lessors.reload.readable_by?(user1)).to eq true
      expect(rh_lessors.reload.readable_by?(user2)).to eq true
      expect(rh_lessors.reload.readable_by?(user3)).to eq false
    end
  end

end
